package com.zanxiang.manage.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.manage.domain.dto.UserDTO;
import com.zanxiang.manage.domain.vo.UserVO;
import com.zanxiang.mybatis.entity.User;

import java.util.List;
import java.util.Map;

/**
 * @author : lingfeng
 * @time : 2022-06-08
 * @description : 用户信息
 */
public interface UserService extends IService<User> {

    /**
     * 查询玩家详细信息
     */
    UserVO getUserInfo(Long userId);

    /**
     * 玩家相关条件查询用户信息
     *
     * @param userId    : 用户id
     * @param channelId : 渠道id
     * @param userName  : 用户名称
     * @param nickname  : 用户昵称
     * @return : 返回用户信息map
     */
    Map<Long, UserDTO> userCondition(Long userId, Long channelId, String userName, String nickname);

    /**
     * 根据玩家账号或者昵称模糊查询玩家列表
     *
     * @param userId    : 用户id
     * @param channelId : 渠道id
     * @param userName  : 玩家账号
     * @param nickname  : 玩家昵称
     * @return : 返回玩家信息
     */
    List<UserDTO> getUserList(Long userId, Long channelId, String userName, String nickname);

    /**
     * 根据用户id查询信息
     *
     * @param userId : 返回用户信息
     * @return : 返回用户信息
     */
    UserDTO getById(Long userId);
}
